@@ -493,8 +493,12 @@ class PaintIbaXmlParser:
                     anode = AnnotatedNode.from_element(node)
                     anode.annotations = self.extract_annotations(node)
                     annotated_node_collection.add(anode)
-        except Exception as e:
+        # except AttributeError as e:  # When 'gene_symbol' is absent; crash for now
+        #     print(xml_path, e)
+        except AssertionError as e:  # When file is null; do not crash, just report out
             print(xml_path, e)
+        # except Exception as e:  # All others; allow crash to investigate
+        #     print(xml_path, e)
 
         return annotated_node_collection
 
